Method: GnuplotRB::Dataset#initialize
- Defined in:
- lib/gnuplotrb/staff/dataset.rb
#initialize(data, **options) ⇒ Dataset
Create new dataset out of given string with math function or filename. If data isn’t a string it will create datablock to store data.
65 66 67 68 |
# File 'lib/gnuplotrb/staff/dataset.rb', line 65 def initialize(data, **) # run method by name send(INIT_HANDLERS[data.class], data, ) end |