Method: GnuplotRB::Plottable#to_canvas
- Defined in:
- lib/gnuplotrb/mixins/plottable.rb
#to_canvas(path = nil, **options) ⇒ String
Output to plot to according image format.
All of #to_|terminal_name| methods are handled with #method_missing.
Gnuplot offers possibility to output graphics to many image formats. The easiest way to to so is to use #to_<plot_name> methods.
|
|
# File 'lib/gnuplotrb/mixins/plottable.rb', line 183
|